This is an automated email from the ASF dual-hosted git repository.

ptupitsyn pushed a commit to branch ignite-12458
in repository https://gitbox.apache.org/repos/asf/ignite.git


The following commit(s) were added to refs/heads/ignite-12458 by this push:
     new 39eb875  Rename in all comments
39eb875 is described below

commit 39eb875c3104f933942f61d8f9bd067b0e6d4cbb
Author: Pavel <[email protected]>
AuthorDate: Wed Dec 25 21:00:57 2019 +0300

    Rename in all comments
---
 .../ignite/thin/ignite_client_configuration.h        |  4 ++--
 .../thin-client/src/impl/affinity/affinity_manager.h |  2 +-
 .../thin-client/src/impl/cache/cache_client_impl.cpp |  2 +-
 .../cpp/thin-client/src/impl/data_channel.h          |  2 +-
 .../platforms/cpp/thin-client/src/impl/data_router.h |  6 +++---
 modules/platforms/cpp/thin-client/src/impl/message.h |  8 ++++----
 .../Client/Cache/PartitionAwarenessTest.cs           |  8 ++++----
 .../Client/ClientReconnectCompatibilityTest.cs       |  2 +-
 .../Client/IgniteClientConfiguration.cs              |  2 +-
 .../Impl/Client/Cache/CacheClient.cs                 | 20 ++++++++++----------
 .../Impl/Client/ClientFailoverSocket.cs              |  4 ++--
 11 files changed, 30 insertions(+), 30 deletions(-)

diff --git 
a/modules/platforms/cpp/thin-client/include/ignite/thin/ignite_client_configuration.h
 
b/modules/platforms/cpp/thin-client/include/ignite/thin/ignite_client_configuration.h
index 33c2df6..d14f830 100644
--- 
a/modules/platforms/cpp/thin-client/include/ignite/thin/ignite_client_configuration.h
+++ 
b/modules/platforms/cpp/thin-client/include/ignite/thin/ignite_client_configuration.h
@@ -211,7 +211,7 @@ namespace ignite
              *
              * Disabled by default.
              *
-             * @param enable Enable affinity awareness.
+             * @param enable Enable partition awareness.
              */
             void SetPartitionAwareness(bool enable)
             {
@@ -252,7 +252,7 @@ namespace ignite
             /** SSL client certificate authority path */
             std::string sslCaFile;
 
-            /** Affinity Awareness. */
+            /** Partition awareness. */
             bool partitionAwareness;
         };
     }
diff --git 
a/modules/platforms/cpp/thin-client/src/impl/affinity/affinity_manager.h 
b/modules/platforms/cpp/thin-client/src/impl/affinity/affinity_manager.h
index dab1ef8..a14ba0e 100644
--- a/modules/platforms/cpp/thin-client/src/impl/affinity/affinity_manager.h
+++ b/modules/platforms/cpp/thin-client/src/impl/affinity/affinity_manager.h
@@ -55,7 +55,7 @@ namespace ignite
                     /**
                      * Update affinity.
                      *
-                     * @param groups Affinity awareness groups.
+                     * @param groups Partition awareness groups.
                      * @param ver Affinity topology version.
                      */
                     void UpdateAffinity(const 
std::vector<PartitionAwarenessGroup>& groups, const AffinityTopologyVersion& 
ver);
diff --git 
a/modules/platforms/cpp/thin-client/src/impl/cache/cache_client_impl.cpp 
b/modules/platforms/cpp/thin-client/src/impl/cache/cache_client_impl.cpp
index 9b43b82..1422707 100644
--- a/modules/platforms/cpp/thin-client/src/impl/cache/cache_client_impl.cpp
+++ b/modules/platforms/cpp/thin-client/src/impl/cache/cache_client_impl.cpp
@@ -51,7 +51,7 @@ namespace ignite
                 {
                     DataRouter& router0 = *router.Get();
 
-                    if (router0.IsAffinityAwarenessEnabled())
+                    if (router0.IsPartitionAwarenessEnabled())
                     {
                         affinity::SP_AffinityAssignment affinityInfo = 
router0.GetAffinityAssignment(id);
 
diff --git a/modules/platforms/cpp/thin-client/src/impl/data_channel.h 
b/modules/platforms/cpp/thin-client/src/impl/data_channel.h
index d44c5a5..425071d 100644
--- a/modules/platforms/cpp/thin-client/src/impl/data_channel.h
+++ b/modules/platforms/cpp/thin-client/src/impl/data_channel.h
@@ -60,7 +60,7 @@ namespace ignite
                 /** Version 1.2.0. */
                 static const ProtocolVersion VERSION_1_2_0;
                 
-                /** Version 1.4.0. Added: Affinity Awareness support, IEP-23. 
*/
+                /** Version 1.4.0. Added: Partition awareness support, IEP-23. 
*/
                 static const ProtocolVersion VERSION_1_4_0;
 
                 /** Current version. */
diff --git a/modules/platforms/cpp/thin-client/src/impl/message.h 
b/modules/platforms/cpp/thin-client/src/impl/message.h
index 262534b..8fdb867 100644
--- a/modules/platforms/cpp/thin-client/src/impl/message.h
+++ b/modules/platforms/cpp/thin-client/src/impl/message.h
@@ -773,7 +773,7 @@ namespace ignite
                 /**
                  * Constructor.
                  *
-                 * @param groups Affinity Awareness Groups.
+                 * @param groups Partition awareness Groups.
                  */
                 CachePartitionsResponse(std::vector<PartitionAwarenessGroup>& 
groups);
 
@@ -800,9 +800,9 @@ namespace ignite
                 }
 
                 /**
-                 * Get affinity awareness groups.
+                 * Get partition awareness groups.
                  *
-                 * @return Affinity awareness groups.
+                 * @return Partition awareness groups.
                  */
                 const std::vector<PartitionAwarenessGroup>& GetGroups() const
                 {
@@ -813,7 +813,7 @@ namespace ignite
                 /** Affinity topology version. */
                 AffinityTopologyVersion topologyVersion;
 
-                /** Affinity awareness groups. */
+                /** Partition awareness groups. */
                 std::vector<PartitionAwarenessGroup>& groups;
             };
 
diff --git a/modules/platforms/cpp/thin-client/src/impl/data_router.h 
b/modules/platforms/cpp/thin-client/src/impl/data_router.h
index 409bd16..2b27ae8 100644
--- a/modules/platforms/cpp/thin-client/src/impl/data_router.h
+++ b/modules/platforms/cpp/thin-client/src/impl/data_router.h
@@ -182,11 +182,11 @@ namespace ignite
                 void RefreshAffinityMapping(const std::vector<int32_t>& 
cacheIds);
 
                 /**
                  * Checked whether affinity awareness enabled.
                  *
                  * @return @c true if affinity awareness enabled.
                  */
-                bool IsAffinityAwarenessEnabled() const
+                bool IsPartitionAwarenessEnabled() const
                 {
                     return config.IsPartitionAwareness();
                 }
@@ -182,11 +182,11 @@ namespace ignite
 
                 /**
-                 * Checked whether affinity awareness enabled.
+                 * Checked whether partition awareness enabled.
                  *
@@ -182,11 +182,11 @@ namespace ignite
                  *
-                 * @return @c true if affinity awareness enabled.
+                 * @return @c true if partition awareness enabled.
                  */
diff --git 
a/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/Cache/PartitionAwarenessTest.cs
 
b/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/Cache/PartitionAwarenessTest.cs
index 2ea8245..f599cba 100644
--- 
a/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/Cache/PartitionAwarenessTest.cs
+++ 
b/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/Cache/PartitionAwarenessTest.cs
@@ -33,7 +33,7 @@ namespace Apache.Ignite.Core.Tests.Client.Cache
     using NUnit.Framework;
 
     /// <summary>
-    /// Tests affinity awareness functionality.
+    /// Tests partition awareness functionality.
     /// </summary>
     public class PartitionAwarenessTest : ClientTestBase
     {
@@ -274,7 +274,7 @@ namespace Apache.Ignite.Core.Tests.Client.Cache
         [Test]
         public void 
ReplicatedCacheGet_RepeatedCall_DoesNotRequestAffinityMapping()
         {
-            // Test cache for which affinity awareness is not applicable.
+            // Test cache for which partition awareness is not applicable.
             var cfg = new CacheClientConfiguration("replicated_cache") 
{CacheMode = CacheMode.Replicated};
             var cache = Client.CreateCache<int, int>(cfg);
 
@@ -292,7 +292,7 @@ namespace Apache.Ignite.Core.Tests.Client.Cache
                 .Where(r => r.Requests.Length > 0)
                 .ToArray();
 
-            // All requests should go to a single (default) node, because 
affinity awareness is not applicable.
+            // All requests should go to a single (default) node, because 
partition awareness is not applicable.
             Assert.AreEqual(1, reqs.Length);
 
             // There should be only one partitions request.
@@ -327,7 +327,7 @@ namespace Apache.Ignite.Core.Tests.Client.Cache
                     .Distinct()
                     .ToArray();
 
-                // Affinity awareness disabled - all requests go to same 
socket, picked with round-robin on connect.
+                // Partition awareness disabled - all requests go to same 
socket, picked with round-robin on connect.
                 Assert.AreEqual(1, requestTargets.Length);
             }
         }
diff --git 
a/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/ClientReconnectCompatibilityTest.cs
 
b/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/ClientReconnectCompatibilityTest.cs
index 13e17ec..8135d86 100644
--- 
a/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/ClientReconnectCompatibilityTest.cs
+++ 
b/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/ClientReconnectCompatibilityTest.cs
@@ -32,7 +32,7 @@ namespace Apache.Ignite.Core.Tests.Client
     public class ClientReconnectCompatibilityTest
     {
         /// <summary>
-        /// Tests that client reconnect to an old server node disables 
affinity awareness.
+        /// Tests that client reconnect to an old server node disables 
partition awareness.
         /// </summary>
         [Test]
         public void TestReconnectToOldNodeDisablesPartitionAwareness()
diff --git 
a/modules/platforms/dotnet/Apache.Ignite.Core/Client/IgniteClientConfiguration.cs
 
b/modules/platforms/dotnet/Apache.Ignite.Core/Client/IgniteClientConfiguration.cs
index 8024187..c602be5 100644
--- 
a/modules/platforms/dotnet/Apache.Ignite.Core/Client/IgniteClientConfiguration.cs
+++ 
b/modules/platforms/dotnet/Apache.Ignite.Core/Client/IgniteClientConfiguration.cs
@@ -209,7 +209,7 @@ namespace Apache.Ignite.Core.Client
         public string Password { get; set; }
 
         /// <summary>
-        /// Gets or sets a value indicating whether affinity awareness should 
be enabled.
+        /// Gets or sets a value indicating whether partition awareness should 
be enabled.
         /// <para />
         /// Default is false: only one connection is established at a given 
moment to a random server node.
         /// When true: for cache operations, Ignite client attempts to send 
the request directly to
diff --git 
a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/Cache/CacheClient.cs 
b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/Cache/CacheClient.cs
index 9f186bb..a4e361d 100644
--- 
a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/Cache/CacheClient.cs
+++ 
b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/Cache/CacheClient.cs
@@ -605,7 +605,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out op with affinity awareness.
+        /// Does the out op with partition awareness.
         /// </summary>
         private void DoOutOpAffinity(ClientOp opId, TK key)
         {
@@ -613,7 +613,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out op with affinity awareness.
+        /// Does the out op with partition awareness.
         /// </summary>
         private void DoOutOpAffinity(ClientOp opId, TK key, TV val)
         {
@@ -621,7 +621,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out op with affinity awareness.
+        /// Does the out op with partition awareness.
         /// </summary>
         private Task DoOutOpAsync(ClientOp opId, Action<BinaryWriter> 
writeAction = null)
         {
@@ -629,7 +629,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out op with affinity awareness.
+        /// Does the out op with partition awareness.
         /// </summary>
         private Task DoOutOpAffinityAsync(ClientOp opId, TK key, 
Action<BinaryWriter> writeAction = null)
         {
@@ -647,7 +647,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out in op with affinity awareness.
+        /// Does the out in op with partition awareness.
         /// </summary>
         private T DoOutInOpAffinity<T>(ClientOp opId, TK key, 
Func<IBinaryStream, T> readFunc)
         {
@@ -661,7 +661,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out in op with affinity awareness.
+        /// Does the out in op with partition awareness.
         /// </summary>
         private T DoOutInOpAffinity<T>(ClientOp opId, TK key, 
Action<BinaryWriter> writeAction,
             Func<IBinaryStream, T> readFunc)
@@ -676,7 +676,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out in op with affinity awareness.
+        /// Does the out in op with partition awareness.
         /// </summary>
         private T DoOutInOpAffinity<T>(ClientOp opId, TK key, TV val, 
Func<IBinaryStream, T> readFunc)
         {
@@ -704,7 +704,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out in op with affinity awareness.
+        /// Does the out in op with partition awareness.
         /// </summary>
         private Task<T> DoOutInOpAffinityAsync<T>(ClientOp opId, TK key, 
Action<BinaryWriter> writeAction,
             Func<IBinaryStream, T> readFunc)
@@ -714,7 +714,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out in op with affinity awareness.
+        /// Does the out in op with partition awareness.
         /// </summary>
         private Task<T> DoOutInOpAffinityAsync<T>(ClientOp opId, TK key, TV 
val, Func<IBinaryStream, T> readFunc)
         {
@@ -732,7 +732,7 @@ namespace Apache.Ignite.Core.Impl.Client.Cache
         }
 
         /// <summary>
-        /// Does the out in op with affinity awareness.
+        /// Does the out in op with partition awareness.
         /// </summary>
         private Task<T> DoOutInOpAffinityAsync<T>(ClientOp opId, TK key, 
Func<IBinaryStream, T> readFunc)
         {
diff --git 
a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/ClientFailoverSocket.cs
 
b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/ClientFailoverSocket.cs
index 9cc3cac..0ed2392 100644
--- 
a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/ClientFailoverSocket.cs
+++ 
b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Client/ClientFailoverSocket.cs
@@ -116,7 +116,7 @@ namespace Apache.Ignite.Core.Impl.Client
         }
 
         /// <summary>
-        /// Performs a send-receive operation with affinity awareness.
+        /// Performs a send-receive operation with partition awareness.
         /// </summary>
         public T DoOutInOpAffinity<T, TKey>(
             ClientOp opId,
@@ -132,7 +132,7 @@ namespace Apache.Ignite.Core.Impl.Client
         }
 
         /// <summary>
-        /// Performs an async send-receive operation with affinity awareness.
+        /// Performs an async send-receive operation with partition awareness.
         /// </summary>
         public Task<T> DoOutInOpAffinityAsync<T, TKey>(
             ClientOp opId,

Reply via email to